;;;  -*- mode: LISP; Package: CL-USER; Syntax: COMMON-LISP;  Base: 10 -*-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; 
;;; Author      : Mike Byrne
;;; Copyright   : (c)2000-2 Rice U./Mike Byrne, All Rights Reserved
;;; Availability: public domain
;;; Address     : Rice University
;;;             : Psychology Department
;;;             : Houston,TX 77251-1892
;;;             : byrne@acm.org
;;; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; 
;;; Filename    : color-text.lisp
;;; Version     : r3
;;; 
;;; Description : Add-on to support colored text in standard MCL dialog
;;;             : items.
;;; 
;;; Bugs        : 
;;; 
;;; Todo        : This should really be rolled into BUILD-STRING-FEATS so
;;;             : it can work everywhere.
;;; 
;;; ----- History -----
;;; 00.03.10 Mike Byrne
;;;             :  Incept date.
;;; 01.07.03 mdb
;;;             : Changed to use Dan's color convention.
;;; 2002.04.14 mdb [r3]
;;;             : Added black to MCL-COLOR->SYMBOL.  Duh.
;;; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defmethod build-features-for :around ((self static-text-dialog-item)
                                          (vis-mod vision-module))
  (let ((feats (call-next-method))
        (color (mcl-color->symbol (part-color self :text))))
    (mapcar #'(lambda (f)
                (setf (color f) color)
                f)
            feats)))



(defun mcl-color->symbol (mcl-color)
  "Given an MCL color code, return a symbol representing that color.  Unknown colors get mapped to COLOR-RRRRR-GGGGG-BBBBB."
  (case mcl-color
    (#.*black-color* 'black)
    (#.*green-color* 'green)
    (#.*red-color* 'red)
    (#.*blue-color* 'blue)
    (#.*brown-color* 'brown)
    (#.*purple-color* 'purple)
    (#.*pink-color* 'pink)
    (#.*orange-color* 'orange)
    (#.*dark-gray-color* 'dark-gray)
    (#.*light-blue-color* 'light-blue)
    (#.*white-color* 'white)
    (#.*light-gray-color* 'light-gray)
    (#.*dark-green-color* 'dark-green)
    (#.*tan-color* 'tan)
    (#.*yellow-color* 'yellow)
    (otherwise (intern (format nil "COLOR-~5,'0d-~5,'0d-~5,'0d" 
                               (color-red mcl-color) 
                               (color-green mcl-color) 
                               (color-blue mcl-color))))))
