;;;  -*- mode: LISP; Package: CL-USER; Syntax: COMMON-LISP;  Base: 10 -*-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; 
;;; Author      : Dan Bothell
;;; Copyright   : (c)2000 CMU/Dan Bothell, All Rights Reserved
;;; Availability: public domain
;;; Address     : Carnegie Mellon University
;;;             : Psychology Department
;;;             : Pittsburgh, PA 15213
;;;             : db30+@andrew.cmu.edu
;;; 
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; 
;;; Filename    : view-line-virtual.lisp
;;; Version     : r0 
;;; 
;;; Description : virtual version of the view-line.lisp file - works with the
;;;             : R/PM virtual views.
;;; Bugs        : 
;;; 
;;; Todo        : 
;;;
;;; ----- History -----
;;;
;;; 01.02.13 Dan Bothell
;;;             : Incept date.  Basically copied from the view-line.lisp
;;;             : file and simplified because it doesn't need to be able to
;;;             : draw itself, or be concerned about which end is which.
;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;; The base class for the view based lines. 

(defclass v-liner (virtual-view)
  ())


(defmethod point-in-click-region-p ((self v-liner) where)
  "Method needed by R/PM so that if the mouse is clicked on the view it
   doesn't get handled by this view, and is passed on to the next"
  (declare (ignore where))
  nil)


(defmethod build-features-for ((lnr v-liner) (vis-mod vision-module))
  "Convert the view to a feature to be placed into the visual icon"
  
  (make-instance 'line-feature
     :color  (color lnr)
     :end1-x (x-pos lnr) 
     :end1-y (y-pos lnr)
     :end2-x (width lnr) 
     :end2-y (height lnr)
     :x (floor (/ (+ (x-pos lnr) (width lnr)) 2))
     :y (floor (/ (+ (y-pos lnr) (height lnr)) 2))
     :width (abs (- (x-pos lnr) (width lnr)))
     :height (abs (- (y-pos lnr) (height lnr)))))


(defmethod feat-to-dmo ((feat line-feature))
  "Convert the line-feature from the visual icon to a DMO (chunk in ACT-R)
   when the feature is attended to"
  (setf (attended-p feat) t)
  (make-dme (dmo-id feat) (kind feat)
            `(screen-pos ,(id (xy-to-dmo (xy-loc feat) t))
              value ,(val feat)
              color ,(color feat)
              height ,(height feat)
              width ,(width feat)
              end1-x ,(end1-x feat)
              end1-y ,(end1-y feat)
              end2-x ,(end2-x feat)
              end2-y ,(end2-y feat))
            :obj (screen-obj feat)
            :where :external))

